@@ -25,6 +25,10 @@ def shaving(r_list: List[int], p_list: List[int], q_list: List[int], UB: int) ->
         fu = fw = op.r
         org_q = op.q
         v = calc_q(op.p, org_q)
+        if fw >= v:
+            # 窓の左端と右端が同じ位置にあるとき対策（窓が[1, 1]みたいな状況）
+            # もっと賢い実装があるかも知れないが，時間もないし正直そこまで計さん時間大きくならないので取り敢えず無視
+            continue
         while True:
             op.r, op.q = fu, calc_q(op.p, fw)
             if has_schedule(job, UB):
